<template>
  <el-dialog
    title="详情"
    width="60%"
    :modal="true"
    :visible.sync="visible"
    :top="'15vh'"
    :close-on-click-modal="false"
    :append-to-body="true"
    :destroy-on-close="true"
    @close="close"
  >
    <el-row :gutter="20">
      <el-col :span="8">
        <span>入库单号：</span>
        <span>{{ detail.businessFormCode }}</span>
      </el-col>
      <el-col :span="8">
        <span>入库仓库：</span>
        <span>{{ detail.goodsTemplateName }}</span>
      </el-col>
      <el-col :span="8">
        <span>所属机构：</span>
        <span>{{ detail.agencyId }}</span>
      </el-col>
    </el-row>
    <el-row :gutter="20" style="margin-top: 20px">
      <el-col :span="8">
        <span>状态：</span>
        <span>{{ detail.states==1?'待入库':'已入库' }}</span>
      </el-col>
      <el-col :span="8">
        <span>创建人：</span>
        <span>{{ detail.buyerName }}</span>
      </el-col>
      <el-col :span="8">
        <span>入库时间：</span>
        <span>{{ detail.time }}</span>
      </el-col>
    </el-row>
    <el-row :gutter="20" style="margin-top: 20px">
      <el-col class="img-row" :span="24">
        <span>采购手续照片：</span>
        <div class="img-box"></div>
      </el-col>
    </el-row>
    <div class="goods-card" v-for="(goodsItem, goodsIndex) in detail.procureGoods" :key="goodsIndex">
      <el-row :gutter="20">
        <el-col :span="8">
          <span>物品分类：</span>
          <span>{{ goodsItem.baseCategoryId }}</span>
        </el-col>
        <el-col :span="8">
          <span>物品名称：</span>
          <span>{{ goodsItem.baseGoodsTemplateId }}</span>
        </el-col>
        <el-col :span="8">
          <span>供货商：</span>
          <span>{{ goodsItem.supplier }}</span>
        </el-col>
      </el-row>
      <el-table :data="goodsItem.models" :stripe="true" style="margin-top: 20px;">
        <el-table-column prop="baseGoodsModelsId" label="规格型号" align="center">
          <template slot-scope="scope">
            {{ scope.row.baseGoodsModelsId }}
          </template>
        </el-table-column>
        <el-table-column label="单位" align="center">
          <template slot-scope="scope">
            {{ scope.row.unit }}
          </template>
        </el-table-column>
        <el-table-column prop="price" label="现有库存" align="center">
          <template slot-scope="scope">
            <el-input v-model="scope.row.price"></el-input>
          </template>
        </el-table-column>
        <el-table-column prop="counts" label="出库数量" align="center">
          <template slot-scope="scope">
            <el-input v-model="scope.row.counts"></el-input>
          </template>
        </el-table-column>
      </el-table>
    </div>
  </el-dialog>
</template>
<script>
import {
  procureDetail,
} from '@/api/stock/procure/purchaseOrder';
export default {
  data() {
    return {
      visible: false,
      detail: {
        businessFormCode:'',
        goodsTemplateName:'',
        agencyId:'',
        states:'',
        createName:'',
        time:'',
        procureGoods:[{},{}]
      },
    };
  },
  methods: {
    open(id) {
      this.visible = true;
      procureDetail({ id }).then(res=>{
        this.detail = res
      })
    },
    close() {
      this.visible = false;
    },
  },
};
</script>
<style lang="scss" scoped>
.img-row {
  display: flex;
  align-content: center;
}
.img-box {
  display: inline-block;
  width: 80px;
  height: 80px;
  background: #f9f9f9;
  margin-right: 20px;
  img {
    width: 100%;
  }
}

.goods-card {
  position: relative;
  background: #f6f6f6;
  padding: 20px;
  box-sizing: border-box;
  border-radius: 4px;
  background-color: #f9f9f9;
  margin-top: 20px;
  &:nth-of-type(1) {
    margin-top: 0;
  }
}
</style>
